@@ -33,7 +33,9 @@ def add_catalogs(parser, with_clts=False):
         cli_util.add_catalog_spec(parser, 'clts')
 
 
-def warning(args, msg, dataset=None):
+def warning(args, msg, dataset=None, warnings=None):
     if dataset:
         msg = '{0}: {1}'.format(colored(dataset.id, 'blue', attrs=['bold']), msg)
     args.log.warning(msg)
+    if warnings is not None:
+        warnings.append(msg)
